@@ -161,6 +161,17 @@ engine_opts = [
         default=1024,
         help=_('The default maximum size in KB of large text fields '
                'of runtime execution objects. Use -1 for no limit.')
+    ),
+    cfg.IntOpt(
+        'execution_integrity_check_delay',
+        default=20,
+        help=_('A number of seconds since the last update of a task'
+               ' execution in RUNNING state after which Mistral will'
+               ' start checking its integrity, meaning that if all'
+               ' associated actions/workflows are finished its state'
+               ' will be restored automatically. If this property is'
+               ' set to a negative value Mistral will never be doing '
+               ' this check.')
     )
 ]
 
@@ -194,6 +205,43 @@ executor_opts = [
     )
 ]
 
+scheduler_opts = [
+    cfg.FloatOpt(
+        'fixed_delay',
+        default=1,
+        min=0.1,
+        help=(
+            'Fixed part of the delay between scheduler iterations, '
+            'in seconds. '
+            'Full delay is defined as a sum of "fixed_delay" and a random '
+            'delay limited by "random_delay".'
+        )
+    ),
+    cfg.FloatOpt(
+        'random_delay',
+        default=0,
+        min=0,
+        help=(
+            'Max value of the random part of the delay between scheduler '
+            'iterations, in seconds. '
+            'Full delay is defined as a sum of "fixed_delay" and a random '
+            'delay limited by this property.'
+        )
+    ),
+]
+
+cron_trigger_opts = [
+    cfg.BoolOpt(
+        'enabled',
+        default=True,
+        help=(
+            'If this value is set to False then the subsystem of cron triggers'
+            ' is disabled. Disabling cron triggers increases system'
+            ' performance.'
+        )
+    ),
+]
+
 event_engine_opts = [
     cfg.HostAddressOpt(
         'host',
@@ -336,6 +384,8 @@ CONF = cfg.CONF
 API_GROUP = 'api'
 ENGINE_GROUP = 'engine'
 EXECUTOR_GROUP = 'executor'
+SCHEDULER_GROUP = 'scheduler'
+CRON_TRIGGER_GROUP = 'cron_trigger'
 EVENT_ENGINE_GROUP = 'event_engine'
 PECAN_GROUP = 'pecan'
 COORDINATION_GROUP = 'coordination'
@@ -344,6 +394,7 @@ PROFILER_GROUP = profiler.list_opts()[0][0]
 KEYCLOAK_OIDC_GROUP = "keycloak_oidc"
 OPENSTACK_ACTIONS_GROUP = 'openstack_actions'
 
+
 CONF.register_opt(wf_trace_log_name_opt)
 CONF.register_opt(auth_type_opt)
 CONF.register_opt(js_impl_opt)
@@ -354,6 +405,8 @@ CONF.register_opt(expiration_token_duration)
 CONF.register_opts(api_opts, group=API_GROUP)
 CONF.register_opts(engine_opts, group=ENGINE_GROUP)
 CONF.register_opts(executor_opts, group=EXECUTOR_GROUP)
+CONF.register_opts(scheduler_opts, group=SCHEDULER_GROUP)
+CONF.register_opts(cron_trigger_opts, group=CRON_TRIGGER_GROUP)
 CONF.register_opts(
     execution_expiration_policy_opts,
     group=EXECUTION_EXPIRATION_POLICY_GROUP
@@ -372,8 +425,14 @@ CLI_OPTS = [
 
 default_group_opts = itertools.chain(
     CLI_OPTS,
-    [wf_trace_log_name_opt, auth_type_opt, js_impl_opt, rpc_impl_opt,
-     rpc_response_timeout_opt, expiration_token_duration]
+    [
+        wf_trace_log_name_opt,
+        auth_type_opt,
+        js_impl_opt,
+        rpc_impl_opt,
+        rpc_response_timeout_opt,
+        expiration_token_duration
+    ]
 )
 
 CONF.register_cli_opts(CLI_OPTS)
