@@ -190,7 +190,12 @@ def publish_variables(task_ex, task_spec):
 
     wf_ex = task_ex.workflow_execution
 
-    expr_ctx = ContextView(task_ex.in_context, wf_ex.context, wf_ex.input)
+    expr_ctx = ContextView(
+        get_current_task_dict(task_ex),
+        task_ex.in_context,
+        wf_ex.context,
+        wf_ex.input
+    )
 
     if task_ex.name in expr_ctx:
         LOG.warning(
@@ -232,8 +237,18 @@ def evaluate_task_outbound_context(task_ex):
     :param task_ex: DB task.
     :return: Outbound task Data Flow context.
     """
+
+    # NOTE(rakhmerov): 'task_ex.in_context' has the SQLAlchemy specific
+    # type MutableDict. So we need to create a shallow copy using dict(...)
+    # initializer and use it. It's enough to be safe in order to manipulate
+    # with entries of the result dictionary, like adding more entries.
+    # However, we must not change values themselves because they are
+    # shared between the original dictionary and the newly created.
+    # It's better to avoid using the method copy.deepcopy() because on
+    # dictionaries with many entries it significantly increases memory
+    # footprint and reduces performance.
     in_context = (
-        copy.deepcopy(dict(task_ex.in_context))
+        dict(task_ex.in_context)
         if task_ex.in_context is not None else {}
     )
 
@@ -258,19 +273,14 @@ def evaluate_workflow_output(wf_ex, wf_output, ctx):
     return output or ctx
 
 
-def add_current_task_to_context(ctx, task_id, task_name):
-    ctx['__task_execution'] = {
-        'id': task_id,
-        'name': task_name
+def get_current_task_dict(task_ex):
+    return {
+        '__task_execution': {
+            'id': task_ex.id,
+            'name': task_ex.name
+        }
     }
 
-    return ctx
-
-
-def remove_internal_data_from_context(ctx):
-    if '__task_execution' in ctx:
-        del ctx['__task_execution']
-
 
 def add_openstack_data_to_context(wf_ex):
     wf_ex.context = wf_ex.context or {}
@@ -285,9 +295,7 @@ def add_openstack_data_to_context(wf_ex):
 def add_execution_to_context(wf_ex):
     wf_ex.context = wf_ex.context or {}
 
-    wf_ex.context['__execution'] = {
-        'id': wf_ex.id
-    }
+    wf_ex.context['__execution'] = {'id': wf_ex.id}
 
 
 def add_environment_to_context(wf_ex):
