@@ -125,8 +125,6 @@ class DirectWorkflowController(base.WorkflowController):
             elif not t_s:
                 t_s = self.wf_spec.get_tasks()[task_ex.name]
 
-            data_flow.remove_internal_data_from_context(ctx)
-
             triggered_by = [
                 {
                     'task_id': task_ex.id,
@@ -170,13 +168,15 @@ class DirectWorkflowController(base.WorkflowController):
     def evaluate_workflow_final_context(self):
         ctx = {}
 
-        for t_ex in self._find_end_task_executions():
-            ctx = utils.merge_dicts(
-                ctx,
-                data_flow.evaluate_task_outbound_context(t_ex)
-            )
+        for batch in self._find_end_task_executions_as_batches():
+            if not batch:
+                break
 
-            data_flow.remove_internal_data_from_context(ctx)
+            for t_ex in batch:
+                ctx = utils.merge_dicts(
+                    ctx,
+                    data_flow.evaluate_task_outbound_context(t_ex)
+                )
 
         return ctx
 
@@ -212,7 +212,7 @@ class DirectWorkflowController(base.WorkflowController):
 
         return True
 
-    def _find_end_task_executions(self):
+    def _find_end_task_executions_as_batches(self):
         def is_end_task(t_ex):
             try:
                 return not self._has_outbound_tasks(t_ex)
@@ -223,13 +223,15 @@ class DirectWorkflowController(base.WorkflowController):
                 # of given task also.
                 return True
 
-        return list(
-            filter(
-                is_end_task,
-                lookup_utils.find_completed_task_executions(self.wf_ex.id)
-            )
+        batches = lookup_utils.find_completed_task_executions_as_batches(
+            self.wf_ex.id
         )
 
+        for batch in batches:
+            yield list(
+                filter(is_end_task, batch)
+            )
+
     def _has_outbound_tasks(self, task_ex):
         # In order to determine if there are outbound tasks we just need
         # to calculate next task names (based on task outbound context)
@@ -248,6 +250,7 @@ class DirectWorkflowController(base.WorkflowController):
         t_name = task_ex.name
 
         ctx_view = data_flow.ContextView(
+            data_flow.get_current_task_dict(task_ex),
             ctx or data_flow.evaluate_task_outbound_context(task_ex),
             self.wf_ex.context,
             self.wf_ex.input
